@@ -4,7 +4,7 @@ use 5.8.0;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '0.8.4';
+$VERSION = '0.8.5';
 
 1;
 
@@ -21,17 +21,17 @@ C<perl -MCPAN -e "install Bundle::W3C::Validator">
 =head1 CONTENTS
 
  CGI 2.81
- Config::General 2.19
+ Config::General 2.31
  Encode
  Encode::HanExtra
- Encode::JIS2K
- File::Spec
+ File::Spec::Functions
  HTML::Encoding 0.52
- HTML::Parser 3.25
+ HTML::Parser 3.24
  HTML::Template 2.6
- LWP::UserAgent 1.90
+ LWP::UserAgent 2.032
  Net::IP
  SGML::Parser::OpenSP
+ String::Approx
  URI
  XML::LibXML
 
@@ -51,7 +51,7 @@ The W3C Markup Validator Team, E<lt>www-validator@w3.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 1994-2007 World Wide Web Consortium, (Massachusetts
+Copyright (C) 1994-2009 World Wide Web Consortium, (Massachusetts
 Institute of Technology, European Research Consortium for Informatics
 and Mathematics, Keio University). All Rights Reserved. This work is
 distributed under the W3C(R) Software License [1] in the hope that it
